==> dynamic-datasource-spring-boot-starter-2.5.6-sources.jar: com/baomidou/dynamic/datasource/provider/AbstractDataSourceProvider.java <==
/**
 * Copyright © 2018 organization baomidou
 * <pre>
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * <pre/>
 */
package com.baomidou.dynamic.datasource.provider;

import com.baomidou.dynamic.datasource.DynamicDataSourceCreator;
import com.baomidou.dynamic.datasource.spring.boot.autoconfigure.DataSourceProperty;
import java.util.HashMap;
import java.util.Map;
import javax.sql.DataSource;
import lombok.AllArgsConstructor;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;


@Slf4j
public abstract class AbstractDataSourceProvider implements DynamicDataSourceProvider {

  @Autowired
  private  DynamicDataSourceCreator dynamicDataSourceCreator;

  protected Map<String, DataSource> createDataSourceMap(
      Map<String, DataSourceProperty> dataSourcePropertiesMap) {
    Map<String, DataSource> dataSourceMap = new HashMap<>(dataSourcePropertiesMap.size());
    for (Map.Entry<String, DataSourceProperty> item : dataSourcePropertiesMap.entrySet()) {
      String pollName = item.getKey();
      DataSourceProperty dataSourceProperty = item.getValue();
      dataSourceProperty.setPollName(pollName);
      dataSourceMap.put(pollName, dynamicDataSourceCreator.createDataSource(dataSourceProperty));
    }
    return dataSourceMap;
  }
}

==> dynamic-datasource-spring-boot-starter-2.5.7-sources.jar: com/baomidou/dynamic/datasource/provider/AbstractDataSourceProvider.java <==
/**
 * Copyright © 2018 organization baomidou
 * <pre>
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 * <pre/>
 */
package com.baomidou.dynamic.datasource.provider;

import com.baomidou.dynamic.datasource.DynamicDataSourceCreator;
import com.baomidou.dynamic.datasource.spring.boot.autoconfigure.DataSourceProperty;
import java.util.HashMap;
import java.util.Map;
import javax.sql.DataSource;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;


@Slf4j
public abstract class AbstractDataSourceProvider implements DynamicDataSourceProvider {

  @Autowired
  private DynamicDataSourceCreator dynamicDataSourceCreator;

  protected Map<String, DataSource> createDataSourceMap(
      Map<String, DataSourceProperty> dataSourcePropertiesMap) {
    Map<String, DataSource> dataSourceMap = new HashMap<>(dataSourcePropertiesMap.size() * 2);
    for (Map.Entry<String, DataSourceProperty> item : dataSourcePropertiesMap.entrySet()) {
      String pollName = item.getKey();
      DataSourceProperty dataSourceProperty = item.getValue();
      dataSourceProperty.setPollName(pollName);
      dataSourceMap.put(pollName, dynamicDataSourceCreator.createDataSource(dataSourceProperty));
    }
    return dataSourceMap;
  }
}
